SpriteAnimator class

Constructors

SpriteAnimator()

Properties

animations ↔ List<SpriteAnimation>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(SpriteAnimation options) → SpriteAnimation
free(SpriteAnimation animation) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(int delta) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited