Interpolant class

Abstract base class of interpolants over parametric samples.

The parameter domain is one dimensional, typically the time or a path along a curve defined by the data.

The sample values can have any dimensionality and derived classes may apply special interpretations to the data.

This class provides the interval seek in a Template Method, deferring the actual interpolation to derived classes.

Time complexity is O(1) for linear access crossing at most two points and O(log N) for random access, where N is the number of positions.

References:

http://www.oodesign.com/template-method-pattern.html

Implementers

Constructors

Interpolant(List<num> parameterPositions, List<num> sampleValues, int valueSize, List? resultBuffer)
parameterPositions -- array of positions

Properties

cachedIndex ↔ int
getter/setter pair
defaultSettings ↔ Map<String, dynamic>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parameterPositions ↔ List<num>
getter/setter pair
resultBuffer ↔ List?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleValues ↔ List<num>
getter/setter pair
settings ↔ Map<String, dynamic>?
getter/setter pair
valueSize ↔ int
getter/setter pair

Methods

afterEnd(int v1, dynamic v2, dynamic v3) → List?
beforeStart(int v1, dynamic v2, dynamic v3) → List?
copySampleValue(int index) → List?
evaluate(num t) → List?
Evaluate the interpolant at position t.
getSettings() → Map<String, dynamic>
interpolate(int i1, num t0, num t, num t1) → List?
intervalChanged(int v1, int v2, int v3) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited