LinearInterpolant class

final interpolant = LinearInterpolant(
  [0,0],
  [0,0],
  1,
	[0]
);
interpolant.evaluate( 0.5 );
Inheritance

Constructors

LinearInterpolant(List<num> parameterPositions, List<num> sampleValues, int sampleSize, List? resultBuffer)
parameterPositions -- array of positions

Properties

cachedIndex ↔ int
getter/setter pairinherited
defaultSettings ↔ Map<String, dynamic>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
parameterPositions ↔ List<num>
getter/setter pairinherited
resultBuffer ↔ List?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleValues ↔ List<num>
getter/setter pairinherited
settings ↔ Map<String, dynamic>?
getter/setter pairinherited
valueSize ↔ int
getter/setter pairinherited

Methods

afterEnd(int v1, dynamic v2, dynamic v3) → List?
inherited
beforeStart(int v1, dynamic v2, dynamic v3) → List?
inherited
copySampleValue(int index) → List?
inherited
evaluate(num t) → List?
Evaluate the interpolant at position t.
inherited
getSettings() → Map<String, dynamic>
inherited
interpolate(int i1, num t0, num t, num t1) → List?
override
intervalChanged(int v1, int v2, int v3) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited