clone method
recursive -- if true, descendants of the object are also cloned. Default
is true.
Returns a clone of this object and optionally all descendants.
Implementation
@override
Group clone ([bool? recursive = true]) {
return Group()..copy(this, recursive);
}