three_js_animations library
Classes
- AnimationAction
-
AnimationActions schedule the performance of the animations which are
stored in
AnimationClips. - AnimationBinding
- AnimationClip
- An AnimationClip is a reusable set of keyframe tracks which represent an animation.
- AnimationMixer
- The AnimationMixer is a player for animations on a particular object in the scene. When multiple objects in the scene are animated independently, one AnimationMixer may be used for each object.
- AnimationObject
-
This is almost identical to an
Group. Its purpose is to make working with animatins of objects syntactically clearer. - AnimationObjectGroup
- A group of objects that receives a shared animation state.
- AnimationUtils
- An object with various functions to assist with animations, used internally.
- BooleanKeyframeTrack
- A Track of Boolean keyframe values.
- ColorKeyframeTrack
- A Track of keyframe values that represent color.
- Composite
- CubicInterpolant
- Fast and simple cubic spline interpolant.
- DiscreteInterpolant
- Interpolant that evaluates to the sample value at the position preceeding the parameter.
- Interpolant
- Abstract base class of interpolants over parametric samples.
- KeyframeTrack
- A KeyframeTrack is a timed sequence of keyframes, which are composed of lists of times and related values, and which are used to animate a specific property of an object.
- LinearInterpolant
-
final interpolant = LinearInterpolant( [0,0], [0,0], 1, [0] ); interpolant.evaluate( 0.5 ); - NumberKeyframeTrack
- A Track of numeric keyframe values.
- PropertyBinding
- PropertyMixer
- Buffered scene graph property that allows weighted accumulation; used internally.
- QuaternionKeyframeTrack
- A Track of quaternion keyframe values.
- QuaternionLinearInterpolant
- Spherical linear unit quaternion interpolant.
- SpriteAnimation
- SpriteAnimator
- SpriteTexture
- StringKeyframeTrack
- A Track that interpolates Strings
- VectorKeyframeTrack
- A Track of vectored keyframe values.
Enums
Extensions
Functions
-
getTrackTypeForValueTypeName(
String typeName) → String -
parseKeyframeTrack(
Map< String, dynamic> json) → KeyframeTrack